from setuptools import setup, find_packages
setup(
name='nace',
version='0.0.6',
author='ucabdv1',
author_email='ucabdv1@ucl.ac.uk',
description='A test to see how pypi packages work',
packages=find_packages(),
classifiers=[
'Programming Language :: Python :: 3',
'License :: OSI Approved :: MIT License',
'Operating System :: OS Independent',
],
python_requires='>=3.10',
)

